import baseLexicon from 'htsl-lexicon';
import Component from 'htsl-component';
import anime from 'animejs';

function unwrapExports (x) {
	return x && x.__esModule ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var images = createCommonjsModule(function (module, exports) {
/*
 * @Author: Gilles Coomans
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

exports.default = function (h) {
	return {
		background: function background(url) {
			var backgroundSize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'cover';

			return this.style('background', 'url(' + url + ') no-repeat center center').style('backgroundSize', backgroundSize);
		},
		thumbnail: function thumbnail(src, alt, templ) {
			return this.img(src, h.class('thumbnail').attr('alt', alt || 'image with no alternate text'), templ);
		},
		roundedThumbnail: function roundedThumbnail(src, alt, templ) {
			return this.img(src, h.classes('thumbnail rounded').attr('alt', alt || 'image with no alternate text'), templ);
		}
	};
};
});

var imagesUikit = unwrapExports(images);

var spinner = createCommonjsModule(function (module, exports) {
/*
 * @Author: Gilles Coomans
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

exports.default = function (h) {
	return {
		spinner: function spinner() {
			return this.div(h.class('spinner').div(h.class('double-bounce1')).div(h.class('double-bounce2')));
		}
	};
};
});

var spinnerUikit = unwrapExports(spinner);

/*
 * @Author: Gilles Coomans
 */

var foundation = baseLexicon.createDialect('foundation').addCompounds(imagesUikit).addCompounds(spinnerUikit);

foundation.colorLabels = ['primary', 'secondary', 'success', 'alert', 'warning'];

foundation.components = {};

/*
 * @Author: Gilles Coomans
 * Foundation 6 button api for htsl
 */
foundation.addCompounds(function (h) {
	return {
		iconButton: function iconButton(icon, content) {
			return this.button(h.class('icon-button').faicon(icon), content);
		},

		// basical button
		simpleButton: function simpleButton(content, type, templ) {
			return this.button(h.class(type, !!type).class('button'), content, templ);
		},

		// hollow button (mean just-border style)
		hollowButton: function hollowButton(content, type, templ) {
			return this.button(h.class(type, !!type).classes('button hollow'), content, templ);
		},

		// anchor button
		aButton: function aButton(href, content, type, templ) {
			return this.a(href, h.class(type, !!type).class('button'), content, templ);
		},
		aHollowButton: function aHollowButton(href, content, type, templ) {
			return this.a(href, h.class(type, !!type).classes('button hollow'), content, templ);
		},

		// close button : for closing action : templ = h.data('close') || h.click(...)
		closeButton: function closeButton(templ) {
			return this.button(h.class('close-button').attr('aria-label', 'Close alert').attr('type', 'button').span(h.attr('aria-hidden', 'true'), '\xD7'), templ);
		},
		buttonGroup: function buttonGroup(buttons) {
			return this.div(h.class('button-group'), buttons);
		},
		smallButtonGroup: function smallButtonGroup(buttons) {
			return this.div(h.classes('small button-group'), buttons);
		},
		switchButton: function switchButton(name, text) {
			return this.div(h.class('switch').input('checkbox', '', h.id(name).class('show-for-sr').attr('name', name)).label(h.class('switch-paddle').attr('for', name).span(h.class('show-for-sr').text(text))));
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {
		// BUTTONS
		coloredAPI[color + 'Button'] = function (content, templ) {
			return this.simpleButton(content, color, templ);
		};
		coloredAPI[color + 'AButton'] = function (href, content, templ) {
			return this.aButton(href, content, color, templ);
		};
		coloredAPI[color + 'AHollowButton'] = function (href, content, templ) {
			return this.aHollowButton(href, content, color, templ);
		};
		coloredAPI[color + 'HollowButton'] = function (content, templ) {
			return this.hollowButton(content, color, templ);
		};
	});
	return coloredAPI;
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:11:25
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-03-22 16:31:19
 */
/* global Foundation, $ */

foundation.addCompounds(function (h) {
	return {
		multiLevelAccordionMenu: function multiLevelAccordionMenu(children) {
			return this.div(h.class('multi-level-accordion-menu').ul(h.class('accordion-menu').data('accordionMenu', true).class('vertical'), children, h.onDom(function (node) {
				new Foundation.AccordionMenu($(node), {});
			})));
		},
		multiLevelAccordionSubMenu: function multiLevelAccordionSubMenu(name, depth, children) {
			return this.li(h.a('#', name).ul(h.class('menu').class('vertical').class('sublevel-' + depth), children));
		},
		multiLevelAccordionMenuLeaf: function multiLevelAccordionMenuLeaf(href, content) {
			return this.li(h.a(href, h.class('subitem'), content));
		},
		testAccordionMenu: function testAccordionMenu() {
			return this.multiLevelAccordionMenu(h.multiLevelAccordionMenuLeaf('#', 'hello root 1').multiLevelAccordionSubMenu('Item 1', 1, h.multiLevelAccordionMenuLeaf('#', 'hello world').multiLevelAccordionSubMenu('Item 1.2', 2, h.multiLevelAccordionMenuLeaf('#', 'hello world 1').multiLevelAccordionMenuLeaf('#', 'hello world 2').multiLevelAccordionMenuLeaf('#', 'hello world 3'))).multiLevelAccordionSubMenu('Item 2', 1, h.multiLevelAccordionMenuLeaf('#', 'hello bloupi').multiLevelAccordionMenuLeaf('#', 'hello bloupi 2').multiLevelAccordionSubMenu('Item 2.2', 2, h.multiLevelAccordionMenuLeaf('#', 'hello foo 1').multiLevelAccordionMenuLeaf('#', 'hello foo 2').multiLevelAccordionMenuLeaf('#', 'hello foo 3'))));
		}
	};
});

/*
 * @Author: Gilles Coomans
 */
/* global Foundation, $ */

foundation.addCompounds(function (h) {
	return {
		dropDownMenu: function dropDownMenu(items) {
			return this.ul(h.class('dropdown').class('menu').data('dropdownMenu').each(items, function (item) {
				return this.li(item);
			}));
		},
		dropDownPane: function dropDownPane(content) {
			return this.div(h.class('dropdown-pane').data('dropdown').data('autoFocus', true).onDom(function (node) {
				setTimeout(function () {
					new Foundation.Dropdown($(node), {});
				});
			}), content);
		}
	};
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:09:40
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-07-08 14:22:50
 */
foundation.addCompounds(function (h) {
	return {
		/********************************
   ****************** FORM ********
   ********************************/

		radioSwitch: function radioSwitch(groupName, text) {
			return this.div(h.class('switch').input('radio', '', h.id(name).attr('name', groupName)).label(h.class('switch-paddle').attr('for', name).span(h.class('show-for-sr'), text)));
		},
		fieldSet: function fieldSet(legend, content) {
			return this.tag('fieldset', [h.class('fieldset').tag('legend', legend), content]);
		},
		helpText: function helpText(targetId, text) {
			return this.p(h.class('help-text').attr('id', targetId), text);
		},
		radio: function radio(opt) {
			opt.id = opt.id || opt.name + opt.value;
			return this.input('radio', opt.value, h.attr('name', opt.name).attr('id', opt.id).if(opt.required, h.attr('required', ''))).label(h.attr('for', opt.id), opt.text || opt.value);
		},

		// checkbox: function(id, value, text) {
		// 	return this.input('checkbox', value, h.attr('id', id))
		// 		.label(h.attr('for', id), text);
		// },
		inlineLabelInputRow: function inlineLabelInputRow(opt) {
			return this.div(h.class('row').div(h.class('small-3').class('columns').label(h.class('text-right').class('middle').attr('for', opt.id), opt.label)).div(h.class('small-9').class('columns').input('text', opt.value, h.attr('id', opt.id).if(opt.placeholder, h.attr('placeholder', opt.placeholder)))));
		},
		inputField: function inputField(opts, errors) {
			return this.div(h.class('input-field').if(opts.icon, h.label(h.attr('for', opts.id).icon(opts.icon))).input(opts.type || 'text', typeof opts.val !== 'undefined' ? opts.val : '', h.attr('id', opts.id).attr('placeholder', opts.placeholder).attr('required', opts.required).if(opts.icon, h.class('labeled'))).div(h.visible(errors).class('formfield-error').text(errors && errors.detail)));
		},

		/**
   * an input-group with coloredLabel-input-button
   * @param  {Object} opt { label:String|Template, value:*, required:Bool(false by def), placeholder:String, buttonText:String|Template }
   * @return {Template}     chainable
   */
		inlineColoredLabelInputButton: function inlineColoredLabelInputButton(opt) {
			return this.div(h.class('input-group').span(h.class('input-group-label'), opt.label).input(opt.type || 'text', opt.value || '', h.class('input-group-field').id(opt.id).if(opt.required, h.prop('required', true)).if(opt.placeholder, h.attr('placeholder', opt.placeholder))).div(
			// warning : foundation 6.2.4 button height issue that has been corrected in develop branch for the moment
			// see : https://github.com/zurb/foundation-sites/pull/9308/files
			h.class('input-group-button').primaryButton(opt.buttonText || 'Submit')));
		},
		inlineColoredLabelInput: function inlineColoredLabelInput(opt) {
			return this.div(h.class('input-group').span(h.class('input-group-label'), opt.label).input(opt.type || 'text', opt.value || '', h.class('input-group-field').id(opt.id).if(opt.required, h.prop('required', true)).if(opt.placeholder, h.attr('placeholder', opt.placeholder))));
		},
		fileUploadButton: function fileUploadButton(id, text, handler) {
			return this.label(h.class('button').attr('for', id), text).input('file', '', h.class('show-for-sr').attr('name', 'photo').id(id).on('change', handler));
		}
	};
});

/*
 * @Author: Gilles Coomans
 */

/**
 * Abstract Component for full screen panel with background
 * @abstract
 */
var OverlayPanel = Component.extends(Component, {
	hide: function hide() {
		var _this = this;

		// this.setState({ opened: false });
		var targets = [];
		if (this.panelBackground) targets.push(this.panelBackground);
		if (this.innerPanel) targets.push(this.innerPanel);
		if (!targets.length) this.unmount();else anime({
			targets: targets,
			opacity: 0,
			easing: 'easeInOutQuart',
			duration: this.props.opt.delay || 400,
			complete: function complete() {
				_this.unmount();
			}
		});
	},
	show: function show() {
		// this.setState({ opened: true });
		anime({
			targets: [this.panelBackground, this.innerPanel],
			opacity: 1,
			easing: 'easeInOutQuart',
			duration: this.props.opt.delay || 400,
			complete: function complete() {
				console.log('panel shown'); // eslint-disable-line
			}
		});
	},
	componentDidMount: function componentDidMount() {
		this.show();
	},
	componentWillReceiveProps: function componentWillReceiveProps() {
		this.show();
	},
	render: function render(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.overlayPanel(this.props, this.state, this.renderPanel(firstLevel), this);
	}
});

/**
 * Full screen Confirm Panel Component with background
 */
var ConfirmPanel = Component.extends(OverlayPanel, {
	validate: function validate(e) {
		e.preventDefault();
		this.hide();
		this.state.callback(true);
	},
	cancel: function cancel(e) {
		e.preventDefault();
		this.hide();
		this.state.callback(false);
	},
	renderPanel: function renderPanel(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.class('confirm-panel').warningDialog(h.h3(this.state.title).style('opacity', 0).ref('innerPanel').p(this.state.message).div(h.class('dialog-buttons-container').warningButton(h.click(this.validate), '\u2713').alertButton(h.click(this.cancel), '\xD7')));
	}
});

/**
 * Full screen Alert Panel Component with background
 */
var AlertPanel = Component.extends(OverlayPanel, {
	renderPanel: function renderPanel(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.class('alert-panel').alertDialog(h.h3(this.state.title).style('opacity', 0).ref('innerPanel').p(this.state.message).div(h.class('dialog-buttons-container').alertButton(h.click(this.hide), '\u2713')), h.click(this.hide));
	}
});

/**
 * Full screen Modal Component with background
 */
var UikitModal = Component.extends(OverlayPanel, {
	renderPanel: function renderPanel(firstLevel) {
		var h = foundation.initializer(firstLevel),
		    subcontent = this.props.content || this.content(firstLevel);

		return h.class('uik-modal').div(h.class('modal-panel').style('opacity', 0).ref('innerPanel').div(h.class('modal-panel-content'), typeof subcontent === 'function' ? subcontent(this.state, this.props, this) : subcontent).closeButton(h.click(this.hide)), this.props.template);
	}
});

/**
 ******************* LEXEMS
 */
foundation.addCompounds(function (h) {
	return {
		/**
   * overlay panel. if opt.closeOnBackgroundClick : needs that ctrl implements unmount method
   * @param  {[type]} opt  [description]
   * @param  {[type]} ctrl [description]
   * @return {[type]}      [description]
   */
		overlayPanel: function overlayPanel(props, state, content, ctrl) {
			return h.div(h.class('overlay-panel').class('opened', !!state.opened).ref('panel').if(props.opt.panelClass, h.class(props.opt.panelClass)).if(!props.opt.noBackground, h.overlayPanelBackground(props.opt.closeOnBackgroundClick, ctrl)), content);
		},
		overlayPanelBackground: function overlayPanelBackground(closeOnBackgroundClick, ctrl) {
			return this.div(h.class('overlay-panel-background').ref('panelBackground').style('opacity', 0).if(closeOnBackgroundClick, h.click(function (e) {
				if (e.target === e.currentTarget) ctrl.hide();
			})));
		},

		/***********************************
   *********** DIALOGS PANEL *********
   ***********************************/
		postalConfirmPanel: function postalConfirmPanel(channel) {
			return this.postalComponent(channel, ConfirmPanel, { opt: {} });
		},
		postalAlertPanel: function postalAlertPanel(channel) {
			return this.postalComponent(channel, AlertPanel, {
				opt: {
					closeOnBackgroundClick: true
				}
			});
		},
		postalUikitModal: function postalUikitModal(channel, opt, content) {
			var template = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : undefined;

			return this.postalComponent(channel, UikitModal, { content: content, opt: opt, template: template });
		}
	};
});

Object.assign(foundation.components, {
	OverlayPanel: OverlayPanel,
	UikitModal: UikitModal,
	ConfirmPanel: ConfirmPanel,
	AlertPanel: AlertPanel
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:22:44
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-03-22 19:31:31
 */

foundation.addCompounds(function (h) {
	return {
		backgroundImage: function backgroundImage(url, backgroundSize) {
			backgroundSize = backgroundSize || 'cover';
			return this.style('background', 'url(' + url + ') no-repeat center center').style('backgroundSize', backgroundSize);
		},
		thumbnail: function thumbnail(src, alt, templ) {
			return this.img(src, h.class('thumbnail').attr('alt', alt || 'image with no alternate text'), templ);
		},
		roundedThumbnail: function roundedThumbnail(src, alt, templ) {
			return this.img(src, h.classes('thumbnail rounded').attr('alt', alt || 'image with no alternate text'), templ);
		}
	};
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-06-09 01:31:03
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-06-21 11:22:43
 */

var SidePanel = Component.extends(OverlayPanel, {
	hide: function hide() {
		var _this = this;

		anime({
			targets: this.innerPannel,
			width: 0,
			duration: this.props.opt.delay || 500,
			easing: 'easeInOutQuart',
			complete: function complete() {
				_this.unmount();
			}
		});
	},
	show: function show() {
		console.log('side panel show : ', this.props.opt.width); // eslint-disable-line
		anime({
			targets: this.innerPannel,
			width: this.props.opt.width,
			easing: 'easeInOutQuart',
			duration: this.props.opt.delay || 500,
			complete: function complete() {
				console.log('panel shown'); // eslint-disable-line
			}
		});
	},
	renderPanel: function renderPanel(firstLevel) {
		var h = foundation.initializer(firstLevel),
		    opt = this.props.opt,
		    subcontent = this.props.content || this.content;
		return h.div(h.class('side-panel').ref('innerPannel').style('width', '0px').class('side-panel--' + opt.side).div(h.class('side-panel-content'), typeof subcontent === 'function' ? subcontent(this.state, this.props, this) : subcontent).closeButton(h.click(this.hide)));
	}
});

/**
 ******************* LEXEMS
 */
foundation.addCompounds(function () {
	return {
		postalSidePanel: function postalSidePanel(channel, opt, content) {
			return this.postalComponent(channel, SidePanel, { opt: opt, content: content });
		},
		sidePanel: function sidePanel(opt, content) {
			return this.component(SidePanel, { opt: opt, content: content });
		}
	};
});

foundation.components.SidePanel = SidePanel;

foundation.addCompounds(function (h) {
	return {
		callout: function callout(type, content, templ) {
			return this.div(h.class('callout').class(type), content, templ);
		},
		closableCallout: function closableCallout(type, content, templ) {
			return this.container(function (ctrl) {
				return h.callout(type, content, h.closeButton(h.click(ctrl.unmount))._use(templ));
			});
		},
		dialog: function dialog(type, content, templ) {
			return this.div(h.class('dialog').class(type), content, templ);
		},
		closableDialog: function closableDialog(type, content, templ) {
			return this.container(function (ctrl) {
				return h.dialog(type, content, h.closeButton(h.click(ctrl.unmount))._use(templ));
			});
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {

		var upCaseColor = color[0].toUpperCase() + color.substring(1);

		// DIALOGS AND CALLOUTS
		coloredAPI[color + 'Dialog'] = function (content, templ) {
			return this.dialog(color, content, templ);
		};
		coloredAPI[color + 'Callout'] = function (content, templ) {
			return this.callout(color, content, templ);
		};
		coloredAPI['closable' + upCaseColor + 'Dialog'] = function (content, templ) {
			return this.closableDialog(color, content, templ);
		};
		coloredAPI['closable' + upCaseColor + 'Callout'] = function (content, templ) {
			return this.closableCallout(color, content, templ);
		};
	});
	return coloredAPI;
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-07-08 13:19:40
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-07-08 13:20:48
 */

foundation.addCompounds(function (h) {
	return {
		imageUploadButton: function imageUploadButton(index, ctrl) {
			return h.form(h.class('show-for-sr').attr('enctype', 'multipart/form-data').attr('action', 'post').input('file', '', h.display(false).attr('name', 'photo').on('change', function (e) {
				var fileInput = e.currentTarget,
				    form = fileInput.parentNode;
				if (fileInput.files && fileInput.files[0]) ctrl.uploadPosterImage(index, form).then(function () {
					form.reset();
				});
			}))).iconButton('image', h.classes('box-button').click(function (e) {
				e.currentTarget.previousSibling[0].click();
			}));
		}
	};
});

/**
 * Foundation 6 api for htsl
 */
/* global Foundation, $ */
var index = foundation.addCompounds(function (h) {
	return {
		/**
   * MISC
   */
		faicon: function faicon(type, templ) {
			return this.i(h.class('fa').class('fa-' + type), templ);
		},
		icon: function icon(type) {
			return this.i(h.class('fi-' + type));
		},
		badge: function badge(text, type) {
			return this.span(h.class('badge').if(type, h.class(type)), text);
		},
		coloredLabel: function coloredLabel(text, type) {
			return this.span(h.class('label').if(type, h.class(type)), text);
		},


		/**
   * HELPERS
   */

		tooltip: function tooltip(title, opt) {
			opt = opt || {};
			var tooltip = void 0;
			return this.class('has-tip').if(opt.top, h.class('top')).data('tooltip').attr('role', 'tooltip').data('clickOpen', !opt.noClickOpen).attr('aria-haspopup', true).data('disableHover', !!opt.disableHover).attr('title', title)
			// .data('hoverDelay', opt.hoverDelay || 0)
			.onDom(function (node) {
				tooltip = new Foundation.Tooltip($(node), opt);
			}, null, function () {
				if (tooltip && tooltip.$element) tooltip.destroy();
			});
		},


		// breadcrumb: function(label, elements) {
		// 	return this
		// 		.nav(h.attr('aria-label', label)
		// 			.attr('role', 'navigation')
		// 			.ul(
		// 				h.class('breadcrumbs')
		// 				.li(h.a('#', 'Home'))
		// 				.li(h.a('#', 'Features'))
		// 				.li(h.class('disabled'), 'Gene Splicing')
		// 				.li(
		// 					h.span(h.class('show-for-sr'), 'Current: '),
		// 					' Cloning'
		// 				)
		// 			)
		// 		);
		// },


		/**
   * NAV
   */

		// subNav: function(title, label) {
		// 	return this.ul(
		// 		h.class("sub-nav")
		// 		.class("menu")
		// 		.attr("role", "navigation")
		// 		// label title
		// 		.attr("title", label)
		// 		// title
		// 		.li(h.class("sub-nav-title"), title)
		// 		// children
		// 		.li(
		// 			h.class("active")
		// 			.span(
		// 				h.class("show-for-sr"),
		// 				"You're viewing "
		// 			)
		// 			.a(h.prop("href"), "All")
		// 		)
		// 		.li(h.a(h.attr("href", "#"), "Active"))
		// 		.li(h.a(h.attr("href", "#"), "Pending"))
		// 		.li(h.a(h.attr("href", "#"), "Suspended"))
		// 	);
		// },


		/***********************************
   *************** CARDS *************
   ***********************************/

		productCard: function productCard(title, price, imgSrc, details) {
			return this.div(h.class('product-card').class('item-wrapper').div(h.class('img-wrapper').a('#', h.class('button').class('expand').class('add-to-cart'), 'Add to Cart').a('#', h.img(imgSrc))).a('#', h.h3(title)).h5(price).p(details));
		},


		/***********************************
   *************** CONTAINERS ********
   ***********************************/
		topBar: function topBar(contentLeft, contentRight) {
			return this.div(h.class('top-bar').div(h.class('top-bar-left'), contentLeft).div(h.class('top-bar-right'), contentRight));
		},
		offCanvas: function offCanvas(leftMenuContent, content, rightMenuContent) {
			return this.div(h.class('off-canvas-wrapper').div(h.class('off-canvas-wrapper-inner').data('offCanvasWrapper').if(leftMenuContent, h.div(h.class('off-canvas').class('position-left').attr('id', 'offCanvas').data('offCanvas', true).closeButton(h.data('close')), leftMenuContent)).div(h.class('off-canvas').class('position-right').attr('id', 'offCanvasRight').data('offCanvas', true).data('position', 'right'), content).if(rightMenuContent, h.div(h.class('off-canvas-content').data('offCanvasContent', true).closeButton(h.data('close')), rightMenuContent))));
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {
		coloredAPI[color + 'Badge'] = function (text) {
			return this.badge(text, color);
		};
		coloredAPI[color + 'Label'] = function (text) {
			return this.coloredLabel(text, color);
		};
	});
	return coloredAPI;
});

export default index;
//# sourceMappingURL=index.mjs.map
