'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _htslComponent = require('htsl-component');

var _htslComponent2 = _interopRequireDefault(_htslComponent);

var _lexicon = require('./lexicon');

var _lexicon2 = _interopRequireDefault(_lexicon);

var _animejs = require('animejs');

var _animejs2 = _interopRequireDefault(_animejs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Abstract Component for full screen panel with background
 * @abstract
 */
var OverlayPanel = _htslComponent2.default.extends(_htslComponent2.default, {
	hide: function hide() {
		var _this = this;

		// this.setState({ opened: false });
		var targets = [];
		if (this.panelBackground) targets.push(this.panelBackground);
		if (this.innerPanel) targets.push(this.innerPanel);
		if (!targets.length) this.unmount();else (0, _animejs2.default)({
			targets: targets,
			opacity: 0,
			easing: 'easeInOutQuart',
			duration: this.props.opt.delay || 400,
			complete: function complete() {
				_this.unmount();
			}
		});
	},
	show: function show() {
		// this.setState({ opened: true });
		(0, _animejs2.default)({
			targets: [this.panelBackground, this.innerPanel],
			opacity: 1,
			easing: 'easeInOutQuart',
			duration: this.props.opt.delay || 400,
			complete: function complete() {
				console.log('panel shown'); // eslint-disable-line
			}
		});
	},
	componentDidMount: function componentDidMount() {
		this.show();
	},
	componentWillReceiveProps: function componentWillReceiveProps() {
		this.show();
	},
	render: function render(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.overlayPanel(this.props, this.state, this.renderPanel(firstLevel), this);
	}
});

/**
 * Full screen Confirm Panel Component with background
 */
/*
 * @Author: Gilles Coomans
 */

var ConfirmPanel = _htslComponent2.default.extends(OverlayPanel, {
	validate: function validate(e) {
		e.preventDefault();
		this.hide();
		this.state.callback(true);
	},
	cancel: function cancel(e) {
		e.preventDefault();
		this.hide();
		this.state.callback(false);
	},
	renderPanel: function renderPanel(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.class('confirm-panel').warningDialog(h.h3(this.state.title).style('opacity', 0).ref('innerPanel').p(this.state.message).div(h.class('dialog-buttons-container').warningButton(h.click(this.validate), '\u2713').alertButton(h.click(this.cancel), '\xD7')));
	}
});

/**
 * Full screen Alert Panel Component with background
 */
var AlertPanel = _htslComponent2.default.extends(OverlayPanel, {
	renderPanel: function renderPanel(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.class('alert-panel').alertDialog(h.h3(this.state.title).style('opacity', 0).ref('innerPanel').p(this.state.message).div(h.class('dialog-buttons-container').alertButton(h.click(this.hide), '\u2713')), h.click(this.hide));
	}
});

/**
 * Full screen Modal Component with background
 */
var UikitModal = _htslComponent2.default.extends(OverlayPanel, {
	renderPanel: function renderPanel(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel),
		    subcontent = this.props.content || this.content(firstLevel);

		return h.class('uik-modal').div(h.class('modal-panel').style('opacity', 0).ref('innerPanel').div(h.class('modal-panel-content'), typeof subcontent === 'function' ? subcontent(this.state, this.props, this) : subcontent).closeButton(h.click(this.hide)), this.props.template);
	}
});

/**
 ******************* LEXEMS
 */
_lexicon2.default.addCompounds(function (h) {
	return {
		/**
   * overlay panel. if opt.closeOnBackgroundClick : needs that ctrl implements unmount method
   * @param  {[type]} opt  [description]
   * @param  {[type]} ctrl [description]
   * @return {[type]}      [description]
   */
		overlayPanel: function overlayPanel(props, state, content, ctrl) {
			return h.div(h.class('overlay-panel').class('opened', !!state.opened).ref('panel').if(props.opt.panelClass, h.class(props.opt.panelClass)).if(!props.opt.noBackground, h.overlayPanelBackground(props.opt.closeOnBackgroundClick, ctrl)), content);
		},
		overlayPanelBackground: function overlayPanelBackground(closeOnBackgroundClick, ctrl) {
			return this.div(h.class('overlay-panel-background').ref('panelBackground').style('opacity', 0).if(closeOnBackgroundClick, h.click(function (e) {
				if (e.target === e.currentTarget) ctrl.hide();
			})));
		},

		/***********************************
   *********** DIALOGS PANEL *********
   ***********************************/
		postalConfirmPanel: function postalConfirmPanel(channel) {
			return this.postalComponent(channel, ConfirmPanel, { opt: {} });
		},
		postalAlertPanel: function postalAlertPanel(channel) {
			return this.postalComponent(channel, AlertPanel, {
				opt: {
					closeOnBackgroundClick: true
				}
			});
		},
		postalUikitModal: function postalUikitModal(channel, opt, content) {
			var template = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : undefined;

			return this.postalComponent(channel, UikitModal, { content: content, opt: opt, template: template });
		}
	};
});

Object.assign(_lexicon2.default.components, {
	OverlayPanel: OverlayPanel,
	UikitModal: UikitModal,
	ConfirmPanel: ConfirmPanel,
	AlertPanel: AlertPanel
});

exports.default = OverlayPanel;